# LinguAML

LinguAML is an innovative project that combines the power of Large Language Models (LLMs) with traditional automated machine learning (AML) techniques, with a primary focus on tuning machine learning models for various tasks. By integrating LLMs' capabilities into the AML workflow, LinguAML aims to enhance the performance and efficiency of machine learning models, specifically by automating the process of hyperparameter tuning.

## Development Notes

Check the development notes 👉 [here](https://isaac-fate.github.io/LinguAML/intro.html).
